# History

## 0.1.0 – 2025-10-06

New multivariate Prompter pipeline

* Update ``rolling_window_sequences`` primitives name – [Issue #48](https://github.com/sintel-dev/sigllm/issues/48) by @sarahmish
* Multivariate prompter pipeline – [Issue #47](https://github.com/sintel-dev/sigllm/issues/47) by @sarahmish


## 0.0.4 – 2025-07-31

New benchmarking suite

* Fix primitive names in pipeline – [Issue #46](https://github.com/sintel-dev/sigllm/issues/46) by @sarahmish
* Add parse list of intervals to ``parse_anomaly_response`` – [Issue #43](https://github.com/sintel-dev/sigllm/issues/43) by @sarahmish
* Add paper benchmark results – [Issue #41](https://github.com/sintel-dev/sigllm/issues/41) by @sarahmish
* Enable Unrestricted LLM Output with Parsing + Add One-Shot Anomaly Detection Support – [Issue #39](https://github.com/sintel-dev/sigllm/issues/39) by @scherkao31
* Add benchmarking suite to ``sigllm`` – [Issue #36](https://github.com/sintel-dev/sigllm/issues/36) by @sarahmish


## 0.0.3 - 2025-02-06

Internal improvements and removing support for Python 3.8

* Add entrypoints for mlblocks – [Issue #32](https://github.com/sintel-dev/sigllm/issues/32) by @sarahmish
* Make readme.yml use Python 3.10 – [Issue #30](https://github.com/sintel-dev/sigllm/issues/30) by @sarahmish
* Migrate from setup.py to pyroject.toml to specify project metadata – [Issue #28](https://github.com/sintel-dev/sigllm/issues/28) by @sarahmish


## 0.0.2 - 2024-10-24

New Prompter pipeline.

* Test README with GPT – [Issue #20](https://github.com/sintel-dev/sigllm/issues/20) by @sarahmish
* Mistral-prompter – [Issue #19](https://github.com/sintel-dev/sigllm/issues/19) by @Linh-nk


## 0.0.1 - 2024-09-25

First sigllm release to PyPI: https://pypi.org/project/sigllm/

* Add README – [Issue #17](https://github.com/sintel-dev/sigllm/issues/17) by @sarahmish
* Create a SigLLM API – [Issue #13](https://github.com/sintel-dev/sigllm/issues/13) by @sarahmish
* Add a Quick Example – [Issue #12](https://github.com/sintel-dev/sigllm/issues/12) by @sarahmish
* Forecasting Pipeline – [Issue #11](https://github.com/sintel-dev/sigllm/issues/11) by @sarahmish
* Refactor Transformation Primitives – [Issue #7](https://github.com/sintel-dev/sigllm/issues/7) by @sarahmish
* Forecasting Module – [Issue #2](https://github.com/sintel-dev/sigllm/issues/2) by @sarahmish

